django-boilerplate - timeline
*****************************

Don't expect dates here... But feel free to ISSUE ( https://github.com/jqb/django-boilerplate/issues ) new things You would like to see or change in django-boilerplate!

django-boilerplate beta
=======================

django-boilerplate alpha
========================

django-boilerplate future
=========================

#. django-boilerplate update problem?
#. django 'best coding' practicies (separate project?), coding rules
#. source dir (for desigers to backup their work?)
#. sandbox dir (For code that is not used now anymore but could be used in a project in a near future. For keeping code samples? Maybe it should be kept in separate branches in VCS?)
#. fabric scripts for dev server
#. CSS/JS/HTML starting templates/libs?
#. script/command to remove unecessary things like (README.rst's, ect.)
